@@ -36,17 +36,16 @@ Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
 图片限制：单边分辨率小于2000，转成 Base64 字符串后小于 5MB。
         :type InputUrl: str
         :param _Prompt: 文本描述。
-用于在输入图的基础上引导生成图效果，建议详细描述画面主体、细节、场景等，文本描述越丰富，生成效果越精美。推荐使用中文。最多支持512个 utf-8 字符。
-注意：如果不输入任何文本描述，可能导致较差的效果，建议根据期望的效果输入相应的文本描述。
+用于在输入图的基础上引导生成图效果，增加生成结果中出现描述内容的可能。
+推荐使用中文。最多支持256个 utf-8 字符。
         :type Prompt: str
         :param _NegativePrompt: 反向文本描述。
 用于一定程度上从反面引导模型生成的走向，减少生成结果中出现描述内容的可能，但不能完全杜绝。
-推荐使用中文。最多可传512个 utf-8 字符。
+推荐使用中文。最多可传256个 utf-8 字符。
         :type NegativePrompt: str
         :param _Styles: 绘画风格。
 请在  [智能图生图风格列表](https://cloud.tencent.com/document/product/1668/86250) 中选择期望的风格，传入风格编号。
 推荐使用且只使用一种风格。不传默认使用201（日系动漫风格）。
-如果想要探索风格列表之外的风格，也可以尝试在 Prompt 中输入其他的风格描述。
         :type Styles: list of str
         :param _ResultConfig: 生成图结果的配置，包括输出图片分辨率和尺寸等。
         :type ResultConfig: :class:`tencentcloud.aiart.v20221229.models.ResultConfig`
@@ -60,8 +59,10 @@ Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
 默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
         :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
         :param _Strength: 生成自由度。
-Strength 值越小，生成图和原图越接近。取值范围0~1，不传默认为0.65。
+Strength 值越小，生成图和原图越接近。取值范围0~1，不传默认为0.75。
         :type Strength: float
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
+        :type RspImgType: str
         """
         self._InputImage = None
         self._InputUrl = None
@@ -72,6 +73,7 @@ Strength 值越小，生成图和原图越接近。取值范围0~1，不传默
         self._LogoAdd = None
         self._LogoParam = None
         self._Strength = None
+        self._RspImgType = None
 
     @property
     def InputImage(self):
@@ -145,6 +147,14 @@ Strength 值越小，生成图和原图越接近。取值范围0~1，不传默
     def Strength(self, Strength):
         self._Strength = Strength
 
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
 
     def _deserialize(self, params):
         self._InputImage = params.get("InputImage")
@@ -160,6 +170,7 @@ Strength 值越小，生成图和原图越接近。取值范围0~1，不传默
             self._LogoParam = LogoParam()
             self._LogoParam._deserialize(params.get("LogoParam"))
         self._Strength = params.get("Strength")
+        self._RspImgType = params.get("RspImgType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -177,7 +188,9 @@ class ImageToImageResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _ResultImage: 返回的生成图 Base64 编码。
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
         :type ResultImage: str
         :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -343,11 +356,14 @@ class ResultConfig(AbstractModel):
     def __init__(self):
         r"""
         :param _Resolution: 生成图分辨率
-支持生成以下不同分辨率的图片，对应1:1方图、3:4竖图、4:3横图三种尺寸规格。
-取值：
-● 768:768
-● 768:1024
-● 1024:768
+
+智能文生图支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）、1024:1024（1:1）、720:1280（9:16）、1280:720（16:9）、768:1280（3:5）、1280:768（5:3）、1080:1920（9:16）、1920:1080（16:9）
+
+智能图生图支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）
+
+不传默认使用768:768
+
+示例值：768:768
         :type Resolution: str
         """
         self._Resolution = None
@@ -382,18 +398,22 @@ class TextToImageRequest(AbstractModel):
         r"""
         :param _Prompt: 文本描述。
 算法将根据输入的文本智能生成与之相关的图像。建议详细描述画面主体、细节、场景等，文本描述越丰富，生成效果越精美。
-不能为空，推荐使用中文。最多可传512个 utf-8 字符。
+不能为空，推荐使用中文。最多可传256个 utf-8 字符。
         :type Prompt: str
         :param _NegativePrompt: 反向文本描述。
 用于一定程度上从反面引导模型生成的走向，减少生成结果中出现描述内容的可能，但不能完全杜绝。
-推荐使用中文。最多可传512个 utf-8 字符。
+推荐使用中文。最多可传256个 utf-8 字符。
         :type NegativePrompt: str
         :param _Styles: 绘画风格。
 请在 [智能文生图风格列表](https://cloud.tencent.com/document/product/1668/86249) 中选择期望的风格，传入风格编号。
 推荐使用且只使用一种风格。不传默认使用201（日系动漫风格）。
-如果想要探索风格列表之外的风格，也可以尝试在 Prompt 中输入其他的风格描述。
         :type Styles: list of str
         :param _ResultConfig: 生成图结果的配置，包括输出图片分辨率和尺寸等。
+
+支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）、1024:1024（1:1）、720:1280（9:16）、1280:720（16:9）、720:1440（1:2）、1440:720（2:1）、768:1280（3:5）、1280:768（5:3）、1080:1920（9:16）、1920:1080（16:9），不传默认使用768:768。
+
+示例值：768:768
+
         :type ResultConfig: :class:`tencentcloud.aiart.v20221229.models.ResultConfig`
         :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
 1：添加标识。
@@ -404,6 +424,8 @@ class TextToImageRequest(AbstractModel):
         :param _LogoParam: 标识内容设置。
 默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
         :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
+        :type RspImgType: str
         """
         self._Prompt = None
         self._NegativePrompt = None
@@ -411,6 +433,7 @@ class TextToImageRequest(AbstractModel):
         self._ResultConfig = None
         self._LogoAdd = None
         self._LogoParam = None
+        self._RspImgType = None
 
     @property
     def Prompt(self):
@@ -460,6 +483,14 @@ class TextToImageRequest(AbstractModel):
     def LogoParam(self, LogoParam):
         self._LogoParam = LogoParam
 
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
 
     def _deserialize(self, params):
         self._Prompt = params.get("Prompt")
@@ -472,6 +503,7 @@ class TextToImageRequest(AbstractModel):
         if params.get("LogoParam") is not None:
             self._LogoParam = LogoParam()
             self._LogoParam._deserialize(params.get("LogoParam"))
+        self._RspImgType = params.get("RspImgType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -489,7 +521,9 @@ class TextToImageResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _ResultImage: 返回的生成图 Base64 编码。
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
         :type ResultImage: str
         :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
